@@ -20,6 +20,7 @@ from . import namespace
 from . import sam
 from . import store
 from . import tools
+from . import uuid_generator
 
 from .archive import *
 from .av_reality import *
@@ -30,4 +31,5 @@ from .learn import *
 from .namespace import *
 from .sam import *
 from .store import *
-from .tools import *
\ No newline at end of file
+from .tools import *
+from .uuid_generator import *
\ No newline at end of file
