@@ -9,14 +9,6 @@
 # Copyright © Semantyk 2020. All rights reserved.
 #############################################
 
-from . import admin
-from . import author
-from . import editor
-from . import guest
 from . import user
 
-from .admin import *
-from .author import *
-from .editor import *
-from .guest import *
 from .user import *
\ No newline at end of file
